@@ -26,8 +26,8 @@ auc = function(truth, prob, positive, na_value = NaN, ...) {
   assert_binary(truth, prob = prob, positive = positive, na_value = na_value)
 
   i = which(truth == positive)
-  n_pos = length(i)
-  n_neg = length(truth) - n_pos
+  n_pos = as.numeric(length(i))
+  n_neg = as.numeric(length(truth)) - n_pos
 
   if (n_pos == 0L || n_neg == 0L)
     return(na_value)
